--SeriesCircuit = {};
--
--
--@date: 25/07/2014
--@Author: Bluebaby210		www.mod-portal.com
--@Version: v1.0	release
--
--
--series circuit for lights
--      <Attribute name="Different_Start_Time" type="integer" value="0"/>	ms 1000= 1 second	if two or more parts build in, start is later then different starts for each part 
--		<Attribute name="Time_Between_lights" type="integer" value="0"/>	ms 1000 = 1 second	the time between the next light is on
--      <Attribute name="Lights_stay_on" type="boolean" value="true"/>		lights stay on till all lights on, or only one is on, when the last light on, then all lights show
--      <Attribute name="Number_of_lights" type="integer" value="4"/>		Number of lights in TG with on create, must be two or more.
--      <Attribute name="onCreate" type="scriptCallback" value="modOnCreate.SeriesCircuitOnCreate"/>
--


SeriesCircuit = {}

local SeriesCircuit_mt = Class(SeriesCircuit, Object);
function SeriesCircuit.onCreate(id)
	local SC = SeriesCircuit:new(g_server ~= nil, g_client ~= nil);
    local SCi = g_currentMission:addOnCreateLoadedObject(SC);
    SC:load(id);
    SC:register(true);
end;

function SeriesCircuit:new(isServer, isClient)
    local self = Object:new(isServer, isClient, SeriesCircuit_mt);
    self.className = "SeriesCircuit";
    return self;
end;

function SeriesCircuit:load(id)  
	
	self.count = Utils.getNoNil(getUserAttribute(id, "Number_of_lights"),0);
	self.lightsStayOn = Utils.getNoNil(getUserAttribute(id, "Lights_stay_on"), true);
	self.timeDifferentStart = Utils.getNoNil(getUserAttribute(id, "Different_Start_Time"), 500);
	self.timeForLight = Utils.getNoNil(getUserAttribute(id, "Time_Between_lights"), 1000);
	self.startLightShow = false;
	
	self.number = 0;
    self.timer = 0;
	self.oneTime = true;
	
	self.lights = {};
	if self.count >= 2 then
		for i=1, self.count do
			local child = getChildAt(id, i-1);
			table.insert(self.lights, child);
			setVisibility(child, false);
		end;
	end;
	
	if table.getn(self.lights) >= 2 then
		self.start = true;
	else
		self.start = false;
	end;
end;

function SeriesCircuit:delete()
end;

function SeriesCircuit:update(dt)
	if self.start then
		if not g_currentMission.environment.isSunOn then
			self.oneTime = true;
			if self.startLightShow then
				self.timer = self.timer + dt;
				if self.timer > self.timeForLight then
					self.timer = 0;
					self.number = self.number +	1;
					
					if self.number > self.count then
						self.number = 0;
						self:switchALL();
					else
						self:switch(self.number);
					end;
				end;
			else
				self.timer = self.timer + dt;
				if self.timer > self.timeDifferentStart then
					self.timer = 0;
					self.startLightShow = true;
				end;
			end;
        else
			if self.oneTime then
				self.timer = 0;
				self.number = 0;
				self:switch(self.number);
				self.oneTime = false;
				self.startLightShow = false;
			end;
        end;
	end;
end;

function SeriesCircuit:switchALL()
	if self.lightsStayOn then
		for j = 1,table.getn(self.lights) do
			setVisibility(self.lights[j], j~=j);
		end;
	else
		for j = 1,table.getn(self.lights) do
			setVisibility(self.lights[j], j==j);
		end;
	end;
end;

function SeriesCircuit:switch(light)
	if self.lightsStayOn then
		if not g_currentMission.environment.isSunOn then
			setVisibility(self.lights[light], true);
		else
			for j = 1,table.getn(self.lights) do
				setVisibility(self.lights[j], false);
			end;
		end;
	else
		for j = 1,table.getn(self.lights) do
			setVisibility(self.lights[j], j==light);
		end;
	end;
	
end;

g_onCreateUtil.addOnCreateFunction("SeriesCircuitOnCreate", SeriesCircuit.onCreate);